taash
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

We are following along with
[this](https://github.com/fastai/nbdev_cards) from fastai.

## Install

``` sh
pip install taash
```

## How to use

This library provides a
[`Card`](https://nasheqlbrm.github.io/taash/card.html#card) class that
can be used to create, display and compare playing cards.

``` python
c = Card(suit=1, rank=3)
c
```

    3♦️

suits are numbered according to the following:

``` python
suits
```

    ['♣️', '♦️', '❤️', '♠️']
